---
icon: material/alert-outline
---
# :octicons-heart-fill-24:{ .heart }&nbsp;&nbsp;Support us
You can support us for further developing with any cryptocurrencies


* Ethereum-like networks (eth, bsc...): `0x6f57BA894474B58F6413f8015b478EAE22444F10`
* TRON: `TWroJYdesLt4LHak1LimZjba5owhU7qzg1`
* Bitcoin: `bc1qtlurpqm2038d0cmj26a7nsxafxcfwjtpk7hr6z`


***
Follow us in social media to stay tuned!
